==> indigitall_flutter_plugin-0.5.0.tar.gz: ios/Classes/IndigitallCustomerFlutterPlugin.m <==
//
//  IndigitallCustomerFlutterPlugin.m
//  indigitall_flutter_plugin
//
//  Created by indigitall on 15/10/21.
//

#import "IndigitallCustomerFlutterPlugin.h"
#import <Indigitall/INDevice.h>
#import <Indigitall/INDefaults.h>

@implementation IndigitallCustomerFlutterPlugin

NSString * CALLBACK_CUSTOMER= @"callbackCustomer";
NSString * CALLBACK_CUSTOMER_FIELDS = @"callbackCustomerFields";

+ (void) getCustomer: (FlutterResult _Nonnull)result{
    [CustomerIndigitall getCustomerWithSuccess:^(INCustomer * _Nonnull customer) {
        result([self jsonFromCustomer:customer]);
    } failed:^(INError * _Nonnull error) {
        [self jsonFromError:error withResult:result];
    }];
  
}

+ (void) getCustomerInformation:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    NSArray<NSString *>* fieldNamesList = params[@"fieldNamesList"];
    
    [CustomerIndigitall getCustomerInformationWithFieldNames:fieldNamesList success:^(NSArray<INCustomerField *> * _Nonnull customerFields) {
        result([self jsonFromCustomerFields:customerFields]);
    } failed:^(INError * _Nonnull error) {
        [self jsonFromError:error withResult:result];
    }];

}

+ (void) assignOrUpdateValueToCustomerFields:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    
    [CustomerIndigitall updateValueToCustomerFieldsWithFields:params success:^(INCustomer * _Nonnull customer){
        result([self jsonFromCustomer:customer]);
    } failed:^(INError * _Nonnull error) {
        [self jsonFromError:error withResult:result];
    }];

}

+ (void) deleteValuesFromCustomerFields:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    NSArray<NSString *>* fieldNamesList = params[@"fieldNamesList"];
    [CustomerIndigitall deleteValuesFromCustomerFieldsWithFieldNames:fieldNamesList success:^(INCustomer * _Nonnull customer) {
        result([self jsonFromCustomer:customer]);
    } failed:^(INError * _Nonnull error) {
        [self jsonFromError:error withResult:result];
    }];

}

+ (void) link:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    NSString *code = params[@"externalCode"];
    if (code != nil){
        INDevice *device = [[[INDevice alloc]init]saveExternalCode:code];
        [INDefaults setExternalId:device.externalCode];
        [CustomerIndigitall linkCustomerWithChannel:[self getChannel:params[@"channel"]] success:^{
            result(@"");
        } failed:^(INError * _Nonnull error) {
            [self jsonFromError:error withResult:result];
        }];
    }
    
}

+ (void) unlink:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    [CustomerIndigitall unlinkCustomerWithChannel:[self getChannel:params[@"channel"]] success:^{
        result(@"");
    } failed:^(INError * _Nonnull error) {
        [self jsonFromError:error withResult:result];
    }];    
}

+ (int) getChannel: (NSString *)channel {
    int channelType = 0;
    if ([channel isEqualToString:@"inapp"]) channelType = 1;
    if ([channel isEqualToString:@"chat"]) channelType = 2;
    return  channelType;
}

+ (NSDictionary *) jsonFromCustomer: (INCustomer *) customer{
    NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
    if (customer != nil) {
        obj = [@{
            @"id" : customer._id ?: @"",
            @"customerId": customer._id ?: @"",
            @"applicationId" : customer.applicationId ?: @"",
            @"createdAt": customer.createdAt ?: @"",
            @"updatedAt": customer.updatedAt ?: @""
        } mutableCopy];
    }
    return [obj copy];
}

+ (NSArray<NSDictionary *> *) jsonFromCustomerFields: (NSArray<INCustomerField *>*)customerFields{
    NSMutableArray<NSDictionary *> *array = [[NSMutableArray alloc]init];
    for (int i = 0; i < customerFields.count; i++) {
        if (customerFields[i].customerFieldKey && customerFields[i].customerFieldValue){
            NSMutableDictionary *obj = [[NSMutableDictionary alloc]init];
            obj = [@{
                customerFields[i].customerFieldKey : customerFields[i].customerFieldValue,
            } mutableCopy];
            [array addObject:[obj copy]];
        }
    }
    return [array copy];
}

+ (void) jsonFromError: (INError *)error withResult: (FlutterResult _Nonnull) result {
    result([FlutterError errorWithCode:[NSString stringWithFormat:@"%u",error.errorCode] message:error.message details:nil]);
}

@end

==> indigitall_flutter_plugin-2.0.2.tar.gz: ios/Classes/IndigitallCustomerFlutterPlugin.m <==
//
//  IndigitallCustomerFlutterPlugin.m
//  indigitall_flutter_plugin
//
//  Created by indigitall on 15/10/21.
//

#import "IndigitallCustomerFlutterPlugin.h"
#import <Indigitall/INDevice.h>
#import "IndigitallCustomerFParse.h"
#import <IndigitallCore/INDefaults.h>

@implementation IndigitallCustomerFlutterPlugin

NSString * CALLBACK_CUSTOMER= @"callbackCustomer";
NSString * CALLBACK_CUSTOMER_FIELDS = @"callbackCustomerFields";

+ (void) getCustomer: (FlutterResult _Nonnull)result{
    [CustomerIndigitall getCustomerWithSuccess:^(INCustomer * _Nonnull customer) {
        result([IndigitallCustomerFParse jsonFromCustomer:customer]);
    } failed:^(INError * _Nonnull error) {
        [IndigitallCustomerFParse jsonFromError:error withResult:result];
    }];
  
}

+ (void) getCustomerInformation:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    NSArray<NSString *>* fieldNamesList = params[@"fieldNamesList"];
    
    [CustomerIndigitall getCustomerInformationWithFieldNames:fieldNamesList success:^(NSArray<INCustomerField *> * _Nonnull customerFields) {
        result([IndigitallCustomerFParse jsonFromCustomerFields:customerFields]);
    } failed:^(INError * _Nonnull error) {
        [IndigitallCustomerFParse jsonFromError:error withResult:result];
    }];

}

+ (void) assignOrUpdateValueToCustomerFields:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    
    [CustomerIndigitall updateValueToCustomerFieldsWithFields:params success:^(INCustomer * _Nonnull customer){
        result([IndigitallCustomerFParse jsonFromCustomer:customer]);
    } failed:^(INError * _Nonnull error) {
        [IndigitallCustomerFParse jsonFromError:error withResult:result];
    }];

}

+ (void) deleteValuesFromCustomerFields:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    NSArray<NSString *>* fieldNamesList = params[@"fieldNamesList"];
    [CustomerIndigitall deleteValuesFromCustomerFieldsWithFieldNames:fieldNamesList success:^(INCustomer * _Nonnull customer) {
        result([IndigitallCustomerFParse jsonFromCustomer:customer]);
    } failed:^(INError * _Nonnull error) {
        [IndigitallCustomerFParse jsonFromError:error withResult:result];
    }];

}

+ (void) link:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    NSString *code = params[@"externalCode"];
    if (code != nil){
        INDevice *device = [[[INDevice alloc]init]saveExternalCode:code];
        [INDefaults setExternalId:device.externalCode];
        [CustomerIndigitall linkCustomerWithChannel:[self getChannel:params[@"channel"]] success:^{
            result(@"");
        } failed:^(INError * _Nonnull error) {
            [IndigitallCustomerFParse jsonFromError:error withResult:result];
        }];
    }
    
}

+ (void) unlink:(NSDictionary *_Nullable)params result: (FlutterResult _Nonnull)result{
    [CustomerIndigitall unlinkCustomerWithChannel:[self getChannel:params[@"channel"]] success:^{
        result(@"");
    } failed:^(INError * _Nonnull error) {
        [IndigitallCustomerFParse jsonFromError:error withResult:result];
    }];    
}

+ (int) getChannel: (NSString *)channel {
    int channelType = 0;
    if ([channel isEqualToString:@"inapp"]) channelType = 1;
    if ([channel isEqualToString:@"chat"]) channelType = 2;
    return  channelType;
}


@end
